@@ -50,7 +50,7 @@ def get_transfer(transfer_file, cosmo_params, transfer_fit,
             # Since the function natively calculates the transfer based on k in Mpc^-1,
             # we need to multiply by h.
             t, T = pert.transfer_function_EH(k * cosmo_params.h,
-                                             **cosmo_params.comolopy_dict())
+                                             **cosmo_params.cosmolopy_dict())
             T = np.vstack((np.log(k), np.log(T)))
             del t
     else:
